##  Getting Started
Discover self-built software components and automate inventory building: SAP LeanIX Technology Risk and Compliance allows you to automatically discover and build an inventory of self-built software components such as microservices and underlying IT components. It leverages Software Bill of Materials (SBOMs) and developer libraries already in use by systematically pulling in data from engineering sources through the Self-Built Software Discovery API. The continuous update capability allows teams to efficiently bring in SBOMs and ensure their software inventory stays current. To learn more, see [Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance enables you to automate the discovery of your self-built software by integrating this process into your developer toolchain.").
Understand complex tech architecture: Tech stacks are automatically identified from granular SBOM data by matching libraries against a curated tech stack catalog. If a library matches a tech stack, an IT component is generated and linked to a relevant microservice. In essence, libraries are aggregated as many libraries can match a single tech stack. Currently, the tech stack discovery supports the discovery of frameworks and databases. To learn more, see [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover tech stacks from ingested SBOMs. Add custom tech stacks manually to complete your technology portfolio.").
lt helps you understand complex technical architecture, including service-to-service dependencies and API utilization, so you can manage the lifecycle of your own builds and strengthen your competitive edge.
Understand dependencies between self-built software and critical teams and products: SAP LeanIX Technology Risk and Compliance extends the meta model by adding the microservice fact sheet subtype, along with additional fields and relationships. This allows you to relate various architectural elements and understand dependencies in the business context. To learn more, see [Meta Model Extension](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD#loio275e3cdd7a44101488219c38543d47a2__meta_model_extension).
![View of Self-Built Data Lineage via Relations Explorer](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f9fc17a441014af9ebef6a8d6da78_LowRes.png)
View of Self-Built Data Lineage via Relations Explorer
Identify software vulnerability: The SBOM components are linked to the microservices, and it allows you to investigate the SBOM components in their business context. Using the SBOM explorer, investigate open-source and third-party component usage across applications and teams, instantly identify vulnerabilities during cybersecurity incidents, and quickly implement risk mitigation actions. It also helps prevent legal issues by identifying unauthorized use of licenses. To learn more, see [SBOM Explorer](https://help.sap.com/docs/leanix/ea/sbom-explorer?locale=en-US&state=PRODUCTION&version=CLOUD "The SBOM explorer helps you understand your open-source libraries' usage, manage them, track them during cybersecurity incidents, and quickly take action to address risks and compliance issues.").
Relate the risk assessment to the business level: Increase visibility into the structure and provenance of self-built software and relate the risk assessments to the business level by making use of relevant reports. This enables leadership to better understand how technology risks impact business operations, allowing for more informed decision-making.
Establish technology standards: By establishing technology standards, you can ensure your technology stack remains relevant, containing only necessary, efficient, and beneficial technologies.
  1. With full visibility into your tech landscape, you can define a framework that addresses obsolescence risk, compliance, and security standards. Effective tech stack governance begins with the adoption of clear technical standards.
  2. Analyze the use of open-source components in their business context and decide which technologies to adopt, trial, assess, or move away from using technology assessment attributes on the IT component fact sheet. The assessment methodology is inspired by the [Technology Radar from Thoughtworks![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.thoughtworks.com%2Fen-de%2Fradar "https://www.thoughtworks.com/en-de/radar").
![Technology Assessment Fields in IT Component Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748fc5b7a4410149c15933bceb1cd6a_LowRes.png)
Technology Assessment Fields in IT Component Fact Sheet
  3. Broadcast your adoption decisions with a best-practice tech radar report to encourage standards adoption. It allows you to easily engage all stakeholders in leadership and the developer community to comply with the adopted standards. High engagement from the development team strengthens tech standards adoption, proactive risk management, and tech governance.
![Technology Radar Report to Broadcast Adoption Decisions](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743c0967a441014a20c8809b49eb25e_LowRes.png)
Technology Radar Report to Broadcast Adoption Decisions
